@@ -423,17 +423,17 @@ OsDependent::getOSDetails()
     case QSysInfo::SV_SF_4:
         rv += " ^4 (deprecated)";
         break;
-//    case QSysInfo::SV_API_5_3:
-//        rv += " API version 5.3 release";
-//        break;
-//    case QSysInfo::SV_API_5_4:
-//        rv += " API version 5.4 release";
-//        break;
+    case QSysInfo::SV_API_5_3:
+        rv += " API version 5.3 release";
+        break;
+    case QSysInfo::SV_API_5_4:
+        rv += " API version 5.4 release";
+        break;
     case QSysInfo::SV_Unknown:
         rv += " Unknown";
         break;
     default:
-        rv += QString("really unknown: %1").arg(symVer);
+        rv += QString(" really unknown: %1").arg(symVer);
         break;
     }
 #endif
