@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2010  Yuvraaj Kelkar
+Copyright (C) 2009-2012  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -95,6 +95,12 @@ struct ConversationEntry {
     }
 };
 
+enum GVI_VMailFmt {
+    GVIVFMT_Unknown = 0,
+    GVIVFMT_Mp3,
+    GVIVFMT_Ogg
+};
+
 struct GVInboxEntry
 {
     //! Unique ID per inbox entry.
@@ -116,6 +122,8 @@ struct GVInboxEntry
     //! The duration of the voice mail (if it's a voicemail)
     quint32         vmailDuration;
 
+    GVI_VMailFmt    vmailFormat;
+
     bool            bRead;
     bool            bSpam;
     bool            bTrash;
